PROJECT {
  NAME       = SpaceDocking.ftl;
  TITLE      =SpaceDocking;
  AUTHOR     = T.Carrico;
  DATEFORMAT = YYYY.DD.MM;
  LASTCHANGE = 2005.16.06;
  CREATED    = 2005.24.05;
  SHELL      = ON_LINE;
  SHELLOPTIONS {
    ONLINE_REFRESHTIME  = 55;
    ONLINE_TIMEOUTCOUNT = 1100;
    ONLINE_CODE         = OFF;
    ONLINE_TRACE_BUFFER = (OFF, PAR(0));
    COMMENTS            = ON;
    FTL_BUFFER          = (OFF, PAR(1));
    PASSWORD            = OFF;
    PUBLIC_IO           = ON;
    FAST_CMBF           = OFF;
    FAST_COA            = ON;
    BTYPE               = DOUBLE;
    C_TYPE              = ANSI;
  } /* SHELLOPTIONS */
  MODEL {
    VARIABLE_SECTION {
      LVAR {
        NAME       = AlignAxisRate;
        BASEVAR    = MPS;
        LVRANGE    = MIN(-2.0), MAX(2.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(0.4), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Rate towards/Away from Axis}
        }
        COLOR      = RED (128), GREEN (0), BLUE (0);
        INPUT      = CMBF;
        POS        = -280, -109;
        TERM {
          TERMNAME = away_fast;
          POINTS   = (-2.0, 1.0),
                     (-0.5, 1.0),
                     (-0.1, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = away_slow;
          POINTS   = (-2.0, 0.0),
                     (-0.5, 0.0),
                     (-0.1, 1.0),
                     (0.0, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = Zero;
          POINTS   = (-2.0, 0.0),
                     (-0.1, 0.0),
                     (0.0, 1.0),
                     (0.1, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
        TERM {
          TERMNAME = towards_slow;
          POINTS   = (-2.0, 0.0),
                     (0.0, 0.0),
                     (0.1, 1.0),
                     (0.5, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = towards_fast;
          POINTS   = (-2.0, 0.0),
                     (0.1, 0.0),
                     (0.5, 1.0),
                     (2.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = Alignment;
        BASEVAR    = Meters;
        LVRANGE    = MIN(0.0), MAX(5.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(0.5), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Left/Right Up/Down position from docking target}
        }
        COLOR      = RED (255), GREEN (0), BLUE (0);
        INPUT      = CMBF;
        POS        = -281, -69;
        TERM {
          TERMNAME = OnAxis;
          POINTS   = (0.0, 1.0),
                     (0.7865, 0.0),
                     (5.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
        TERM {
          TERMNAME = Close;
          POINTS   = (0.0, 0.0),
                     (0.7865, 1.0),
                     (3.2161, 0.0),
                     (5.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = Far;
          POINTS   = (0.0, 0.0),
                     (0.7865, 0.0),
                     (3.2161, 1.0),
                     (5.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = X_Distance;
        BASEVAR    = Meters;
        LVRANGE    = MIN(0.0), MAX(500.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(500.0);
        RESOLUTION = XGRID(50.0), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Distance from dock}
        }
        COLOR      = RED (0), GREEN (0), BLUE (255);
        INPUT      = CMBF;
        POS        = -280, -32;
        TERM {
          TERMNAME = x_close;
          POINTS   = (0.0, 1.0),
                     (1.0000000000001, 1.0),
                     (10.0, 0.0),
                     (500.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = x_medium;
          POINTS   = (0.0, 0.0),
                     (1.0000000000001, 0.0),
                     (13.48, 1.0),
                     (100.0, 0.0),
                     (500.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = x_far;
          POINTS   = (0.0, 0.0),
                     (13.48, 0.0),
                     (100.86, 1.0),
                     (500.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = XDot;
        BASEVAR    = MPS;
        LVRANGE    = MIN(-2.0), MAX(2.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(0.4), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Rate towards/Away along X axis}
        }
        COLOR      = RED (128), GREEN (0), BLUE (0);
        INPUT      = CMBF;
        POS        = -278, 12;
        TERM {
          TERMNAME = away_fast;
          POINTS   = (-2.0, 1.0),
                     (-0.5, 1.0),
                     (-0.1, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = away_slow;
          POINTS   = (-2.0, 0.0),
                     (-0.5, 0.0),
                     (-0.1, 1.0),
                     (-0.1, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = Zero;
          POINTS   = (-2.0, 0.0),
                     (-0.1, 0.0),
                     (0.0, 1.0),
                     (0.1, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
        TERM {
          TERMNAME = towards_slow;
          POINTS   = (-2.0, 0.0),
                     (0.1, 0.0),
                     (0.1, 1.0),
                     (0.5, 0.0),
                     (2.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = towards_fast;
          POINTS   = (-2.0, 0.0),
                     (0.1, 0.0),
                     (0.5, 1.0),
                     (2.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = YZ_Alignment;
        BASEVAR    = Meters;
        LVRANGE    = MIN(0.0), MAX(20.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(2.0), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {Sq root of Square of sums of Y and Z - radial distance to Alignment}
        }
        COMMENTTEXT {
          PAR {This variable is used to determine X Engine speed.}
        }
        COLOR      = RED (255), GREEN (0), BLUE (128);
        INPUT      = CMBF;
        POS        = -277, 77;
        TERM {
          TERMNAME = close;
          POINTS   = (0.0, 1.0),
                     (5.0, 1.0),
                     (6.4285, 0.0),
                     (20.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = medium;
          POINTS   = (0.0, 0.0),
                     (5.0, 0.0),
                     (6.4285, 1.0),
                     (15.0, 0.0),
                     (20.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = far;
          POINTS   = (0.0, 0.0),
                     (6.4285, 0.0),
                     (15.0, 1.0),
                     (20.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = z_Axis_Calling;
        BASEVAR    = Units;
        LVRANGE    = MIN(0.0), MAX(1.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(0.1), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        COLOR      = RED (128), GREEN (255), BLUE (0);
        INPUT      = DISPLAY;
        POS        = -173, 144;
      }  /* LVAR */
      LVAR {
        NAME       = AlignEngine;
        BASEVAR    = Newtons;
        LVRANGE    = MIN(-10.0), MAX(10.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(2.0), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        COLOR      = RED (0), GREEN (128), BLUE (0);
        OUTPUT     = COM;
        POS        = 27, -86;
        TERM {
          TERMNAME = TowardLarge;
          POINTS   = (-10.0, 0.0),
                     (-6.6665, 1.0),
                     (-3.3335, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = TowardSmall;
          POINTS   = (-10.0, 0.0),
                     (-6.6665, 0.0),
                     (-3.3335, 1.0),
                     (0.0, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = Zero;
          POINTS   = (-10.0, 0.0),
                     (-3.3335, 0.0),
                     (0.0, 1.0),
                     (3.3335, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
        TERM {
          TERMNAME = AwaySmall;
          POINTS   = (-10.0, 0.0),
                     (0.0, 0.0),
                     (3.3335, 1.0),
                     (6.6665, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = AwayLarge;
          POINTS   = (-10.0, 0.0),
                     (3.3335, 0.0),
                     (6.6665, 1.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
      }  /* LVAR */
      LVAR {
        NAME       = Xengine;
        BASEVAR    = Newtons;
        LVRANGE    = MIN(-10.0), MAX(10.0),
                     MINDEF(0), MAXDEF(65535),
                     DEFAULT_OUTPUT(0.0);
        RESOLUTION = XGRID(2.0), YGRID(0.1),
                     SHOWGRID (ON), SNAPTOGRID(OFF);
        EXPLANATION {
          PAR {X Axis Engine}
        }
        COLOR      = RED (0), GREEN (128), BLUE (128);
        OUTPUT     = COM;
        POS        = 20, 7;
        TERM {
          TERMNAME = very_negative;
          POINTS   = (-10.0, 1.0),
                     (-1.429, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (255), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = negative;
          POINTS   = (-10.0, 0.0),
                     (-1.429, 1.0),
                     (0.0, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (0);
        }
        TERM {
          TERMNAME = zero;
          POINTS   = (-10.0, 0.0),
                     (-1.429, 0.0),
                     (0.0, 1.0),
                     (1.4285, 0.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (0), BLUE (255);
        }
        TERM {
          TERMNAME = positive;
          POINTS   = (-10.0, 0.0),
                     (0.0, 0.0),
                     (1.4285, 1.0),
                     (10.0, 0.0);
          SHAPE    = LINEAR;
          COLOR    = RED (128), GREEN (0), BLUE (0);
        }
        TERM {
          TERMNAME = very_positive;
          POINTS   = (-10.0, 0.0),
                     (1.4285, 0.0),
                     (10.0, 1.0);
          SHAPE    = LINEAR;
          COLOR    = RED (0), GREEN (128), BLUE (128);
        }
      }  /* LVAR */
    }  /* VARIABLE_SECTION */

    OBJECT_SECTION {
      RULEBLOCK {
        NAME        = Align;
        INPUT       = AlignAxisRate, Alignment, X_Distance;
        OUTPUT      = AlignEngine;
        AGGREGATION = (MIN_MAX, PAR (0.0));
        RESULT_AGGR = BSUM;
        POS         = -153, -110;
        RULES {
          IF    AlignAxisRate = away_fast
            AND Alignment = OnAxis
            AND X_Distance = x_close
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = OnAxis
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = OnAxis
            AND X_Distance = x_far
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = Close
            AND X_Distance = x_close
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = Close
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = Close
            AND X_Distance = x_far
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = Far
            AND X_Distance = x_close
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = Far
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_fast
            AND Alignment = Far
            AND X_Distance = x_far
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = OnAxis
            AND X_Distance = x_close
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = OnAxis
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = OnAxis
            AND X_Distance = x_far
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = Close
            AND X_Distance = x_close
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = Close
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = Close
            AND X_Distance = x_far
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = Far
            AND X_Distance = x_close
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = Far
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = away_slow
            AND Alignment = Far
            AND X_Distance = x_far
          THEN  AlignEngine = TowardLarge   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = OnAxis
            AND X_Distance = x_close
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = OnAxis
            AND X_Distance = x_medium
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = OnAxis
            AND X_Distance = x_far
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = Close
            AND X_Distance = x_close
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = Close
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = Close
            AND X_Distance = x_far
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = Far
            AND X_Distance = x_close
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = Far
            AND X_Distance = x_medium
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = Zero
            AND Alignment = Far
            AND X_Distance = x_far
          THEN  AlignEngine = TowardSmall   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = OnAxis
            AND X_Distance = x_close
          THEN  AlignEngine = AwaySmall   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = OnAxis
            AND X_Distance = x_medium
          THEN  AlignEngine = AwaySmall   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = OnAxis
            AND X_Distance = x_far
          THEN  AlignEngine = AwaySmall   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = Close
            AND X_Distance = x_close
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = Close
            AND X_Distance = x_medium
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = Close
            AND X_Distance = x_far
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = Far
            AND X_Distance = x_close
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = Far
            AND X_Distance = x_medium
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = towards_slow
            AND Alignment = Far
            AND X_Distance = x_far
          THEN  AlignEngine = Zero   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = OnAxis
            AND X_Distance = x_close
          THEN  AlignEngine = AwayLarge   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = OnAxis
            AND X_Distance = x_medium
          THEN  AlignEngine = AwayLarge   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = OnAxis
            AND X_Distance = x_far
          THEN  AlignEngine = AwayLarge   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = Close
            AND X_Distance = x_close
          THEN  AlignEngine = AwayLarge   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = Close
            AND X_Distance = x_medium
          THEN  AlignEngine = AwayLarge   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = Close
            AND X_Distance = x_far
          THEN  AlignEngine = AwayLarge   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = Far
            AND X_Distance = x_close
          THEN  AlignEngine = AwaySmall   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = Far
            AND X_Distance = x_medium
          THEN  AlignEngine = AwaySmall   WITH 1.000;
          IF    AlignAxisRate = towards_fast
            AND Alignment = Far
            AND X_Distance = x_far
          THEN  AlignEngine = AwaySmall   WITH 1.000;
        }  /* RULES */
      }  /* RULEBLOCK */
      RULEBLOCK {
        NAME        = X_Engine;
        INPUT       = X_Distance, XDot, YZ_Alignment;
        OUTPUT      = Xengine;
        AGGREGATION = (MIN_MAX, PAR (0.0));
        RESULT_AGGR = BSUM;
        POS         = -154, -13;
        COMMENTTEXT {
          PAR {The X Engine Rule controls the X azis, lateral movement towards the docking hatch.  YZ ALignment is passe din as the SQR of the SUM of the square Z and Y distances}
        }
        RULES {
          IF    X_Distance = x_close
            AND XDot = away_fast
            AND YZ_Alignment = close
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = away_fast
            AND YZ_Alignment = medium
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = away_fast
            AND YZ_Alignment = far
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = away_slow
            AND YZ_Alignment = close
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = away_slow
            AND YZ_Alignment = medium
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = away_slow
            AND YZ_Alignment = far
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = Zero
            AND YZ_Alignment = close
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = Zero
            AND YZ_Alignment = medium
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = Zero
            AND YZ_Alignment = far
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = towards_slow
            AND YZ_Alignment = close
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = towards_slow
            AND YZ_Alignment = medium
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = towards_slow
            AND YZ_Alignment = far
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = towards_fast
            AND YZ_Alignment = close
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = towards_fast
            AND YZ_Alignment = medium
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_close
            AND XDot = towards_fast
            AND YZ_Alignment = far
          THEN  Xengine = very_negative   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = away_fast
            AND YZ_Alignment = close
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = away_fast
            AND YZ_Alignment = medium
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = away_fast
            AND YZ_Alignment = far
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = away_slow
            AND YZ_Alignment = close
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = away_slow
            AND YZ_Alignment = medium
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = away_slow
            AND YZ_Alignment = far
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = Zero
            AND YZ_Alignment = close
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = Zero
            AND YZ_Alignment = medium
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = Zero
            AND YZ_Alignment = far
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = towards_slow
            AND YZ_Alignment = close
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = towards_slow
            AND YZ_Alignment = medium
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = towards_slow
            AND YZ_Alignment = far
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = towards_fast
            AND YZ_Alignment = close
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = towards_fast
            AND YZ_Alignment = medium
          THEN  Xengine = negative   WITH 1.000;
          IF    X_Distance = x_medium
            AND XDot = towards_fast
            AND YZ_Alignment = far
          THEN  Xengine = very_negative   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = away_fast
            AND YZ_Alignment = medium
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = away_fast
            AND YZ_Alignment = far
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = away_fast
            AND YZ_Alignment = close
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = away_slow
            AND YZ_Alignment = medium
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = away_slow
            AND YZ_Alignment = far
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = away_slow
            AND YZ_Alignment = close
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = Zero
            AND YZ_Alignment = close
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = Zero
            AND YZ_Alignment = medium
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = Zero
            AND YZ_Alignment = far
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = towards_slow
            AND YZ_Alignment = close
          THEN  Xengine = very_positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = towards_slow
            AND YZ_Alignment = medium
          THEN  Xengine = positive   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = towards_slow
            AND YZ_Alignment = far
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = towards_fast
            AND YZ_Alignment = close
          THEN  Xengine = zero   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = towards_fast
            AND YZ_Alignment = medium
          THEN  Xengine = very_negative   WITH 1.000;
          IF    X_Distance = x_far
            AND XDot = towards_fast
            AND YZ_Alignment = far
          THEN  Xengine = very_negative   WITH 1.000;
        }  /* RULES */
      }  /* RULEBLOCK */
    }  /* OBJECT_SECTION */
  }  /* MODEL */
}  /* PROJECT */ 
/* fuzzyTECH 5.54k Professional Edition */
/* FT IU 00139 01 ID */
ONLINE {
  TIMESTAMP = 20050616234902UT;
}  /* ONLINE */

NEUROFUZZY {
  LEARNRULE     =RandomMethod;
  STEPWIDTHDOS  = 0.101563;
  STEPWIDTHTERM = 1.000000;
  MAXDEVIATION  = (50.000000, 1.000000, 0.750000);
  AVGDEVIATION  = 0.100000;
  MAXSTEPS      = 100;
  NEURONS       = 1;
  DATASEQUENCE  = RANDOM;
  UPDATEDBGWIN  = OFF;
}  /* NEUROFUZZY */